@@ -7,3 +7,6 @@ from .organization import Organization, Organizations
 from .search import Search
 from .user import User, Users
 from .team import Teams
+from .annotations import Annotations
+from .snapshots import Snapshots
+
