@@ -37,15 +37,23 @@ class Folder(Base):
             json_data["uid"] = uid
         return self.api.POST("/folders", json=json_data)
 
-    def update_folder(self, uid, title):
+    def update_folder(self, uid, title, version=None, overwrite=False):
         """
 
         :param uid:
         :param title:
+        :param version:
+        :param overwrite:
         :return:
         """
+        body = {"title": title}
+        if version is not None:
+            body['version'] = version
+        if overwrite:
+            body['overwrite'] = True
+
         path = "/folders/%s" % uid
-        r = self.api.PUT(path, json={"title": title})
+        r = self.api.PUT(path, json=body)
         return r
 
     def delete_folder(self, uid):
@@ -68,12 +76,12 @@ class Folder(Base):
         r = self.api.GET(path)
         return r
 
-    def get_folder_permissions(self):
+    def get_folder_permissions(self,uid):
         """
 
         :return:
         """
-        path = "/folders/%s/permissions"
+        path = "/folders/%s/permissions" % uid
         r = self.api.GET(path)
         return r
 
