@@ -10,6 +10,8 @@ from .api import (
     User,
     Users,
     Teams,
+    Snapshots,
+    Annotations,
 )
 
 
@@ -22,6 +24,7 @@ class GrafanaFace:
         url_path_prefix="",
         protocol="http",
         verify=True,
+        timeout=5.0,
     ):
         self.api = GrafanaAPI(
             auth,
@@ -30,6 +33,7 @@ class GrafanaFace:
             url_path_prefix=url_path_prefix,
             protocol=protocol,
             verify=verify,
+            timeout=timeout,
         )
         self.admin = Admin(self.api)
         self.dashboard = Dashboard(self.api)
@@ -41,3 +45,5 @@ class GrafanaFace:
         self.user = User(self.api)
         self.users = Users(self.api)
         self.teams = Teams(self.api)
+        self.annotations = Annotations(self.api)
+        self.snapshots = Snapshots(self.api)
